parsedatetime

Package parsedatetime |
[hide private]
[frames] | no frames]

# Source Code for Package parsedatetime

     1  """
     2  parsedatetime.py contains the C{Calendar} class where the C{parse()}
     3  method can be found.
     4
     5  parsedatetime_consts.py contains the C{Constants} class that builds the
     6  various regex values using locale information if available.
     7  """
     8
     9  version = '0.8.3'
    10  author  = 'Mike Taylor and Darshana Chhajed'
    11  license = """
    12  Copyright (c) 2004-2007 Mike Taylor
    13  Copyright (c) 2006-2007 Darshana Chhajed
    14  All rights reserved.
    15
    16  Licensed under the Apache License, Version 2.0 (the "License");
    17  you may not use this file except in compliance with the License.
    18  You may obtain a copy of the License at
    19
    20     http://www.apache.org/licenses/LICENSE-2.0
    21
    22  Unless required by applicable law or agreed to in writing, software
    23  distributed under the License is distributed on an "AS IS" BASIS,
    24  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    25  See the License for the specific language governing permissions and
    26  limitations under the License.
    27  """
    28